containertools.get_first_element_starting_strictly_after_prolated_offset
========================================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_strictly_after_prolated_offset
